@@ -268,8 +268,9 @@ func TestRetryWithBackoff(t *testing.T) {
 			case <-time.After(test.timeout):
 				t.Fatalf("Timeout after %v", test.timeout)
 			}
+
 			if count != test.expectedAttemptsCount-1 {
-				t.Fatalf("Invalid count; want: %d; got: %d", test.expectedAttemptsCount, count)
+				t.Fatalf("Invalid count; got: %d, want: %d", count, test.expectedAttemptsCount-1)
 			}
 		})
 	}
