@@ -1934,3 +1934,59 @@ func TestKeyValueListKeysDuplicates(t *testing.T) {
 		})
 	}
 }
+
+func TestKeyValueConfig(t *testing.T) {
+	s := RunBasicJetStreamServer()
+	defer shutdownJSServerAndRemoveStorage(t, s)
+
+	nc, js := jsClient(t, s)
+	defer nc.Close()
+
+	originalCfg := &nats.KeyValueConfig{
+		Bucket:       "CONFIG_TEST",
+		Description:  "test bucket for config retrieval",
+		MaxValueSize: 1024,
+		History:      10,
+		TTL:          2 * time.Hour,
+		MaxBytes:     1024 * 1024,
+		Storage:      nats.FileStorage,
+		Replicas:     1,
+	}
+
+	kv, err := js.CreateKeyValue(originalCfg)
+	if err != nil {
+		t.Fatalf("Error creating KV: %v", err)
+	}
+
+	status, err := kv.Status()
+	if err != nil {
+		t.Fatalf("Error getting status: %v", err)
+	}
+
+	retrievedCfg := status.Config()
+
+	if retrievedCfg.Bucket != originalCfg.Bucket {
+		t.Errorf("Expected bucket %q, got %q", originalCfg.Bucket, retrievedCfg.Bucket)
+	}
+	if retrievedCfg.Description != originalCfg.Description {
+		t.Errorf("Expected description %q, got %q", originalCfg.Description, retrievedCfg.Description)
+	}
+	if retrievedCfg.MaxValueSize != originalCfg.MaxValueSize {
+		t.Errorf("Expected MaxValueSize %d, got %d", originalCfg.MaxValueSize, retrievedCfg.MaxValueSize)
+	}
+	if retrievedCfg.History != originalCfg.History {
+		t.Errorf("Expected history %d, got %d", originalCfg.History, retrievedCfg.History)
+	}
+	if retrievedCfg.TTL != originalCfg.TTL {
+		t.Errorf("Expected TTL %v, got %v", originalCfg.TTL, retrievedCfg.TTL)
+	}
+	if retrievedCfg.MaxBytes != originalCfg.MaxBytes {
+		t.Errorf("Expected MaxBytes %d, got %d", originalCfg.MaxBytes, retrievedCfg.MaxBytes)
+	}
+	if retrievedCfg.Storage != originalCfg.Storage {
+		t.Errorf("Expected storage %v, got %v", originalCfg.Storage, retrievedCfg.Storage)
+	}
+	if retrievedCfg.Replicas != originalCfg.Replicas {
+		t.Errorf("Expected replicas %d, got %d", originalCfg.Replicas, retrievedCfg.Replicas)
+	}
+}
